;; Generated package description from company.el  -*- no-byte-compile: t -*-
(define-package "company" "1.0.2" "Modular text completion framework" '((emacs "25.1")) :commit "393940f76aec1f2500441d4e0b97f783acbb536b" :maintainer '("Dmitry Gutov" . "dmitry@gutov.dev") :keywords '("abbrev" "convenience" "matching") :url "http://company-mode.github.io/")
